@@ -1,6 +1,7 @@
 import numpy as np
 import pytest
 from numpy.testing import assert_array_equal
+from pytest import approx
 
 import boost_histogram as bh
 
@@ -351,6 +352,30 @@ def test_pick_int_category():
     assert_array_equal(h[:, :, bh.loc(7)].view(), 0)
 
 
+@pytest.mark.parametrize(
+    "ax",
+    [bh.axis.Regular(3, 0, 1), bh.axis.Variable([0, 0.3, 0.6, 1])],
+    ids=["regular", "variable"],
+)
+def test_pick_flowbin(ax):
+    w = 1e-2  # e.g. a cross section for a process
+    x = [-0.1, -0.1, 0.1, 0.1, 0.1]
+    y = [-0.1, 0.1, -0.1, -0.1, 0.1]
+
+    h = bh.Histogram(
+        ax,
+        ax,
+        storage=bh.storage.Weight(),
+    )
+    h.fill(x, y, weight=w)
+
+    uf_slice = h[bh.tag.underflow, ...]
+    assert uf_slice.values(flow=True) == approx(np.array([1, 1, 0, 0, 0]) * w)
+
+    uf_slice = h[..., bh.tag.underflow]
+    assert uf_slice.values(flow=True) == approx(np.array([1, 2, 0, 0, 0]) * w)
+
+
 def test_axes_tuple():
     h = bh.Histogram(bh.axis.Regular(10, 0, 1))
     assert isinstance(h.axes[:1], bh._internal.axestuple.AxesTuple)
@@ -404,3 +429,29 @@ def test_single_flow_bin():
     assert h[3::sum] == 1
 
     assert h[1:2][sum] == 5
+
+
+# issue 579
+
+
+def test_scale_flowbins():
+    w = 1e-1
+    x = np.random.normal(loc=0.4, scale=0.4, size=100)
+
+    h = bh.Histogram(bh.axis.Variable([0, 0.5, 1]), storage=bh.storage.Weight())
+
+    h.fill(x, weight=w)
+
+    ref_value = h.values(flow=True) * 5
+    scale_value = (h * 5).values(flow=True)
+
+    assert scale_value == approx(ref_value)
+
+
+def test_add_flowbins():
+    h = bh.Histogram(bh.axis.Variable([0, 0.5, 1]), storage=bh.storage.Weight())
+
+    ref_value = h.values(flow=True) + 5
+    scale_value = (h + 5).values(flow=True)
+
+    assert scale_value == approx(ref_value)
